from setuptools import setup, find_packages

setup(
    name='tggl_client',
    version='0.1.0',
    description='Tggl python client',
    packages=find_packages(),
    install_requires=[],
    keywords=['Tggl', 'feature flag'],
)